@@ -1,9 +1,13 @@
-#include <R.h>
-#include <Rinternals.h>
-#include <Rmath.h>
-#include <math.h>
-#include <stdlib.h>
+#include <Rcpp.h>
 
+//#include <R.h>
+//#include <Rinternals.h>
+//#include <Rmath.h>
+//#include <math.h>
+//#include <stdlib.h>
+
+#include <cstddef>
+// #include <cstdlib>
 #include <vector>
 
 #include "Functions.h"
